
using System.Runtime.Serialization;
using Syncfusion.Windows.Forms.Grid;
using System.Drawing;


namespace GGC_RefreshGrouping
{    
    public class CustomCellModel : GridTextBoxCellModel
    {
        protected CustomCellModel(SerializationInfo info, StreamingContext context)
            : base(info, context)
        {
        }

        public CustomCellModel(GridModel grid)
            : base(grid)
        {
        }

        public override GridCellRendererBase CreateRenderer(GridControlBase control)
        {
            return new CustomCellRenderer(control, this);
        }

        //used to provide optimal height and width for cell (as in grid.ColWidths.ResizeToFit calls)
        protected override Size OnQueryPrefferedClientSize(Graphics g, int rowIndex, int colIndex, GridStyleInfo style, GridQueryBounds queryBounds)
        {
            Size sz = base.OnQueryPrefferedClientSize(g, rowIndex, colIndex, style, queryBounds);

            //adjust to allow for button width
            sz.Width = sz.Width + ButtonBarSize.Width;

            return sz;
        }
    }
        
    public class CustomCellRenderer : GridTextBoxCellRenderer
    {
        #region Data Members
        
        private IValue m_OldValue;               
                
        #endregion // Data Members

        #region Constructor

        public CustomCellRenderer(GridControlBase grid, GridCellModelBase cellModel)
            : base(grid, cellModel)
        {
                    
        }

        #endregion

        #region Overrides        
                
        protected override bool OnSaveChanges()
        {   
            m_OldValue.Parse(TextBox.Text);
            this.ControlValue = m_OldValue;

            return base.OnSaveChanges();
        }

        protected override void OnInitialize(int rowIndex, int colIndex)
        {
            base.OnInitialize(rowIndex, colIndex);

            m_OldValue = ControlValue as IValue;            
        }

        #endregion       
    }
}